=======
Corsort
=======

.. image:: https://github.com/emczg/corsort/raw/main/docs/logo/logo.png
    :alt: CorSort logo
    :target: https://emczg.github.io/corsort/


.. image:: https://img.shields.io/pypi/v/corsort.svg
        :target: https://pypi.python.org/pypi/corsort
        :alt: PyPI Status

.. image:: https://github.com/emczg/corsort/workflows/build/badge.svg?branch=main
        :target: https://github.com/emczg/corsort/actions?query=workflow%3Abuild
        :alt: Build Status

.. image:: https://github.com/emczg/corsort/workflows/docs/badge.svg?branch=main
        :target: https://github.com/emczg/corsort/actions?query=workflow%3Adocs
        :alt: Documentation Status


.. image:: https://codecov.io/gh/emczg/corsort/branch/main/graphs/badge.svg
        :target: https://codecov.io/gh/emczg/corsort/tree/main
        :alt: Code Coverage



Comparison-Oriented Sort.


* Free software: GNU General Public License v3
* Documentation: https://emczg.github.io/corsort/.


--------
Features
--------

* Implement Corsort, an efficient anytime sorting algorithm.
* Compare Corsort with classical algorithms through Monte-Carlo simulations.

-------
Credits
-------

This package was created with Cookiecutter_ and the `francois-durand/package_helper_2`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`francois-durand/package_helper_2`: https://github.com/francois-durand/package_helper_2
